@@ -55,6 +55,7 @@ __all__ = (
     "DelegateTypeDef",
     "DeleteAccessControlRuleRequestRequestTypeDef",
     "DeleteAliasRequestRequestTypeDef",
+    "DeleteEmailMonitoringConfigurationRequestRequestTypeDef",
     "DeleteGroupRequestRequestTypeDef",
     "DeleteMailboxPermissionsRequestRequestTypeDef",
     "DeleteMobileDeviceAccessOverrideRequestRequestTypeDef",
@@ -66,6 +67,8 @@ __all__ = (
     "DeleteUserRequestRequestTypeDef",
     "DeregisterFromWorkMailRequestRequestTypeDef",
     "DeregisterMailDomainRequestRequestTypeDef",
+    "DescribeEmailMonitoringConfigurationRequestRequestTypeDef",
+    "DescribeEmailMonitoringConfigurationResponseTypeDef",
     "DescribeGroupRequestRequestTypeDef",
     "DescribeGroupResponseTypeDef",
     "DescribeInboundDmarcSettingsRequestRequestTypeDef",
@@ -134,6 +137,7 @@ __all__ = (
     "PaginatorConfigTypeDef",
     "PermissionTypeDef",
     "PutAccessControlRuleRequestRequestTypeDef",
+    "PutEmailMonitoringConfigurationRequestRequestTypeDef",
     "PutInboundDmarcSettingsRequestRequestTypeDef",
     "PutMailboxPermissionsRequestRequestTypeDef",
     "PutMobileDeviceAccessOverrideRequestRequestTypeDef",
@@ -371,6 +375,13 @@ DeleteAliasRequestRequestTypeDef = TypedDict(
     },
 )
 
+DeleteEmailMonitoringConfigurationRequestRequestTypeDef = TypedDict(
+    "DeleteEmailMonitoringConfigurationRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+    },
+)
+
 DeleteGroupRequestRequestTypeDef = TypedDict(
     "DeleteGroupRequestRequestTypeDef",
     {
@@ -477,6 +488,22 @@ DeregisterMailDomainRequestRequestTypeDef = TypedDict(
     },
 )
 
+DescribeEmailMonitoringConfigurationRequestRequestTypeDef = TypedDict(
+    "DescribeEmailMonitoringConfigurationRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+    },
+)
+
+DescribeEmailMonitoringConfigurationResponseTypeDef = TypedDict(
+    "DescribeEmailMonitoringConfigurationResponseTypeDef",
+    {
+        "RoleArn": str,
+        "LogGroupArn": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 DescribeGroupRequestRequestTypeDef = TypedDict(
     "DescribeGroupRequestRequestTypeDef",
     {
@@ -1336,6 +1363,15 @@ class PutAccessControlRuleRequestRequestTypeDef(
     pass
 
 
+PutEmailMonitoringConfigurationRequestRequestTypeDef = TypedDict(
+    "PutEmailMonitoringConfigurationRequestRequestTypeDef",
+    {
+        "OrganizationId": str,
+        "RoleArn": str,
+        "LogGroupArn": str,
+    },
+)
+
 PutInboundDmarcSettingsRequestRequestTypeDef = TypedDict(
     "PutInboundDmarcSettingsRequestRequestTypeDef",
     {
